import{eP as t,eQ as d}from"./outputWidgets.9bb29762.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="cad6be03-d528-41f6-ba28-52ce223bdbc6",e._sentryDebugIdIdentifier="sentry-dbid-cad6be03-d528-41f6-ba28-52ce223bdbc6")}catch{}})();function o(e,n){return t(1,arguments),d(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.3a419a8c.js.map
