import{C as n,A as o}from"./CollapsePanel.a92a9301.js";import{T as t,A as d}from"./Timeline.15fac260.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},b=new Error().stack;b&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[b]="315b4588-b5d3-4c5d-b2fb-1be1edb6ce5e",e._sentryDebugIdIdentifier="sentry-dbid-315b4588-b5d3-4c5d-b2fb-1be1edb6ce5e")}catch{}})();n.Panel=o;n.install=function(e){return e.component(n.name,n),e.component(o.name,o),e};t.Item=d;t.install=function(e){return e.component(t.name,t),e.component(d.name,d),e};
//# sourceMappingURL=index.d5eda63b.js.map
