import{D as u}from"./DeleteOutlined.f8ba9770.js";import{f as o,eG as f}from"./outputWidgets.9bb29762.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="869a2323-a346-4438-a1cd-e71e147b7a35",e._sentryDebugIdIdentifier="sentry-dbid-869a2323-a346-4438-a1cd-e71e147b7a35")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){d(e,a,n[a])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=l({},t,n.attrs);return o(f,l({},r,{icon:u}),null)};i.displayName="DeleteOutlined";i.inheritAttrs=!1;const b=i;export{b as D};
//# sourceMappingURL=DeleteOutlined.e7d9e6ac.js.map
