import{V as c}from"./outputWidgets.9bb29762.js";import{c as s,d as i}from"./index.300c1cf9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="69f0ac1b-dd08-432d-9e73-ada2c3bd6588",e._sentryDebugIdIdentifier="sentry-dbid-69f0ac1b-dd08-432d-9e73-ada2c3bd6588")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:d}=s(i),y=c(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:d,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(d.name,d),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{y as D,t as M,a as Q,d as R,r as W};
//# sourceMappingURL=dayjs.1649cfe2.js.map
