(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="07e43c29-a5c9-48e1-ac35-553ecc07f3a6",e._sentryDebugIdIdentifier="sentry-dbid-07e43c29-a5c9-48e1-ac35-553ecc07f3a6")}catch{}})();const t="/assets/logo.0faadfa2.svg";export{t as _};
//# sourceMappingURL=logo.084e5d7c.js.map
