import{ac as c,V as t,Q as r,f as p}from"./outputWidgets.9bb29762.js";import{B as l,b}from"./Base.abff5e35.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="ac7493e7-d014-42bc-b704-36baa3c309e5",e._sentryDebugIdIdentifier="sentry-dbid-ac7493e7-d014-42bc-b704-36baa3c309e5")}catch{}})();const f=()=>t(t({},r(b(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:d}=s;const{ellipsis:n}=e;c();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),d);return p(l,i,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=f();const g=o;export{g as A};
//# sourceMappingURL=Text.5324981a.js.map
