[data-v-73dd2178]:root{--main-font-family: DM Sans, sans-serif}[data-v-73dd2178]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-73dd2178]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-73dd2178]{background-color:#fff;padding:10px}.kanban-btn[data-v-73dd2178]{font-family:DM Sans,sans-serif;font-size:16px;color:#5a677a;border:none;box-shadow:0 0 4px #0000001f;position:fixed;bottom:48px;right:64px}.page[data-v-68d92933]{display:flex;flex-direction:column;height:100%}.container[data-v-68d92933]{display:flex;justify-content:center;align-items:center;width:100%;flex:1}.form-card[data-v-68d92933]{cursor:pointer}.form-card[data-v-68d92933]:hover{box-shadow:0 0 10px #0000001a}
