import{V as s,f as d,Q as p}from"./outputWidgets.9bb29762.js";import{B as f,b as i}from"./Base.abff5e35.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="98da2861-d8fc-4241-a5f3-89089d581b2e",a._sentryDebugIdIdentifier="sentry-dbid-98da2861-d8fc-4241-a5f3-89089d581b2e")}catch{}})();const y=()=>p(i(),["component"]),r=(a,e)=>{let{slots:t,attrs:o}=e;const n=s(s(s({},a),{component:"div"}),o);return d(f,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=y();const b=r;export{b as A};
//# sourceMappingURL=Paragraph.9dbf4710.js.map
