import{B as d}from"./Base.abff5e35.js";import{A as a}from"./Link.f9998948.js";import{A as o}from"./Paragraph.9dbf4710.js";import{A as r}from"./Text.5324981a.js";import{A as i}from"./Title.b342fcc9.js";import{T as e}from"./Typography.184e8c0b.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="18ddd288-ca1a-47c7-a52e-84f2e41e515e",n._sentryDebugIdIdentifier="sentry-dbid-18ddd288-ca1a-47c7-a52e-84f2e41e515e")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=o;e.Link=a;e.Base=d;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,o),n.component(e.Link.displayName,a),n};
//# sourceMappingURL=index.e7d326b6.js.map
