import"./outputWidgets.9bb29762.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ca26a2fb-7293-4950-9360-a67823e1ff3d",e._sentryDebugIdIdentifier="sentry-dbid-ca26a2fb-7293-4950-9360-a67823e1ff3d")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.c222fac4.js.map
