import{cy as n}from"./outputWidgets.9bb29762.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="8eff9501-a7e5-4f38-a712-cf7349719b10",e._sentryDebugIdIdentifier="sentry-dbid-8eff9501-a7e5-4f38-a712-cf7349719b10")}catch{}})();const t=(e,f,r)=>{n.error({message:e,description:f,onClick:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.b12790e0.js.map
