import{u as s}from"./index.7dcd1439.js";import{d,b as l,ev as c,f as n,u as r}from"./outputWidgets.9bb29762.js";import{g as b}from"./api.8bd36db0.js";import{K as f,L as u}from"./repository.58499269.js";import{_ as g}from"./Navbar.vue_vue_type_script_setup_true_lang.68d5f2a8.js";import{a as y}from"./asyncComputed.ac1a0197.js";import{P as _}from"./repository.2c4dc05e.js";import"./pubsub.90d4935e.js";import"./runnerData.84b552ce.js";import"./url.c222fac4.js";import"./workspaces.53f8033a.js";import"./record.dd7b0559.js";import"./scripts.54747d94.js";import"./envVars.f8fed0f5.js";import"./api.2c2d04af.js";import"./index.cf4c23b9.js";import"./icons.d08bf04b.js";import"./contracts.generated.deda1c64.js";import"./index.fcc99b17.js";import"./ant-design.3940e065.js";import"./index.1ce3173e.js";import"./Modal.8f9ba470.js";import"./Text.5324981a.js";import"./Base.abff5e35.js";import"./Typography.184e8c0b.js";import"./index.e7d326b6.js";import"./Link.f9998948.js";import"./Paragraph.9dbf4710.js";import"./Title.b342fcc9.js";import"./index.b2ab466e.js";import"./index.3a419a8c.js";import"./index.d5eda63b.js";import"./CollapsePanel.a92a9301.js";import"./Timeline.15fac260.js";import"./index.54135072.js";import"./index.2c2899aa.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.d5a2bc8a.js";import"./Card.b91f4cc4.js";import"./TabPane.aa230872.js";import"./hasIn.fa8167cd.js";import"./DownOutlined.56421333.js";import"./index.d6e0013f.js";import"./Form.472b1af8.js";import"./index.3a61abce.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="e082ce30-c86a-403e-82b5-78b290d708d6",o._sentryDebugIdIdentifier="sentry-dbid-e082ce30-c86a-403e-82b5-78b290d708d6")}catch{}})();const fo=d({__name:"Kanban",setup(o){const t=new _(s),i=new u("kanban"),{result:e}=y(b);return(k,w)=>{var m,a,p;return l(),c("div",null,[n(g,{"brand-name":((m=r(e))==null?void 0:m.brandName)||((a=r(e))==null?void 0:a.name),"logo-url":(p=r(e))==null?void 0:p.logoUrl},null,8,["brand-name","logo-url"]),n(f,{"kanban-repository":r(t),storage:r(i)},null,8,["kanban-repository","storage"])])}}});export{fo as default};
//# sourceMappingURL=Kanban.b6cfce56.js.map
