import{C as t,E as d,K as i,a as b,M as f,c,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.f88bcd1c.js";import"./outputWidgets.9bb29762.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="70bbf7c4-fb8d-4b5a-a8bc-a5d3791b8282",e._sentryDebugIdIdentifier="sentry-dbid-70bbf7c4-fb8d-4b5a-a8bc-a5d3791b8282")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,b as KeyMod,f as MarkerSeverity,c as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.85de6b31.js.map
