import{_ as u}from"./Navbar.vue_vue_type_script_setup_true_lang.68d5f2a8.js";import{g as p}from"./api.8bd36db0.js";import{a as _}from"./asyncComputed.ac1a0197.js";import{W as y}from"./WidgetsFrame.ebd50b14.js";import{d as g,eB as b,b as n,ev as h,e as a,u as t,c as f,w as v,ex as d,eD as l,v as w}from"./outputWidgets.9bb29762.js";import"./index.7dcd1439.js";import"./pubsub.90d4935e.js";import"./index.3a61abce.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Base.abff5e35.js";import"./Typography.184e8c0b.js";import"./Text.5324981a.js";import"./runnerData.84b552ce.js";import"./url.c222fac4.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new D().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="42e68f5c-88f3-4a06-86ae-9709f8d9ff83",o._sentryDebugIdIdentifier="sentry-dbid-42e68f5c-88f3-4a06-86ae-9709f8d9ff83")}catch{}})();const k={class:"error"},I={class:"inner-content"},x=g({__name:"Error",setup(o){const r=b(),{result:e}=_(p),c=()=>{const{status:s}=r.params;switch(s){case"404":return{status:s,message:"Page not found."};case"403":return{status:s,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(s,B)=>(n(),h("div",null,[a("div",k,[t(e)?(n(),f(y,{key:0,"main-color":t(e).mainColor,theme:t(e).theme,"font-family":t(e).fontFamily,style:{height:"100vh"}},{default:v(()=>{var i,m;return[t(e)?(n(),f(u,{key:0,"brand-name":((i=t(e))==null?void 0:i.brandName)||((m=t(e))==null?void 0:m.name),"logo-url":t(e).logoUrl},null,8,["brand-name","logo-url"])):d("",!0),a("div",I,[a("h1",null,l(c().status),1),a("p",null,l(c().message),1)])]}),_:1},8,["main-color","theme","font-family"])):d("",!0)])]))}});const D=w(x,[["__scopeId","data-v-befb94cf"]]);export{D as default};
//# sourceMappingURL=Error.a4da68a4.js.map
