import{d as w,eA as N,eB as L,r as b,H as V,a as x,b as a,c as p,w as t,ev as l,eC as v,u as r,cw as $,aD as y,bf as E,f as o,ez as g,I as m,ar as R,eD as T,ex as k,bh as M,v as I,eE as q,eF as z,e as C}from"./outputWidgets.9bb29762.js";import{p as F,w as H,k as P,s as W,a as j,b as G,v as J,c as K,d as O}from"./icons.d08bf04b.js";import{_ as Q}from"./logo.084e5d7c.js";import{B as U}from"./BaseLayout.74bb733b.js";import{N as X}from"./NavbarControls.3d4ab4cd.js";import{c as Y}from"./index.3a61abce.js";import"./workspaces.53f8033a.js";import"./runnerData.84b552ce.js";import"./url.c222fac4.js";import"./record.dd7b0559.js";import"./pubsub.90d4935e.js";import"./asyncComputed.ac1a0197.js";import"./envVars.f8fed0f5.js";import"./index.7dcd1439.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.93d5905e.js";import"./ant-design.3940e065.js";import"./index.1ce3173e.js";import"./Modal.8f9ba470.js";import"./Typography.184e8c0b.js";import"./Link.f9998948.js";import"./Base.abff5e35.js";import"./index.15996575.js";import"./popupNotifcation.b12790e0.js";import"./index.fcc99b17.js";import"./Text.5324981a.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.79f00877.js";import"./Paragraph.9dbf4710.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="871c1c5c-a401-4888-b528-bf75c8a7a5e5",e._sentryDebugIdIdentifier="sentry-dbid-871c1c5c-a401-4888-b528-bf75c8a7a5e5")}catch{}})();const Z={key:0,class:"collapsible"},ee={key:1,class:"collapsible"},te=w({__name:"Sidebar",setup(e){var f;const n=N(),d=L(),c=b((f=d.name)!=null?f:"forms"),i=b(!1),h=()=>{i.value=!i.value},A=V(()=>[{name:"Project",children:[{name:"Stages",icon:F,path:"stages"},{name:"Workflow",icon:H,path:"workflow"},{name:"Threads",icon:P,path:"kanban"}]},{name:"Settings",children:[{name:"Style",icon:W,path:"style"},{name:"Sidebar",icon:j,path:"sidebar"},{name:"Requirements",icon:G,path:"requirements"},{name:"Env Vars",icon:J,path:"env-vars"}]}]),B=_=>{n.push(_.path),c.value=_.path};return(_,pe)=>{const D=x("router-link");return a(),p(r(M),{"inline-collapsed":i.value,style:{display:"flex","flex-direction":"column"}},{default:t(()=>[(a(!0),l(y,null,v(A.value,u=>(a(),p(r($),{key:u.name,title:u.name},{default:t(()=>[(a(!0),l(y,null,v(u.children,s=>(a(),p(r(E),{key:s.name,role:"button",tabindex:"0",onClick:de=>B(s)},{icon:t(()=>[o(m,{class:g({active:c.value===s.path}),path:s.icon,width:"18",height:"18"},null,8,["class","path"])]),default:t(()=>[o(D,{to:s.path,class:g({active:c.value===s.path})},{default:t(()=>[R(T(s.name),1)]),_:2},1032,["to","class"])]),_:2},1032,["onClick"]))),128))]),_:2},1032,["title"]))),128)),i.value?(a(),l("div",Z,[o(m,{path:r(K),onClick:h},null,8,["path"])])):k("",!0),i.value?k("",!0):(a(),l("div",ee,[o(m,{path:r(O),onClick:h},null,8,["path"])]))]),_:1},8,["inline-collapsed"])}}});const ae=I(te,[["__scopeId","data-v-faa20278"]]);const oe={},S=e=>(q("data-v-81cd596e"),e=e(),z(),e),se={class:"logo"},ne=S(()=>C("img",{src:Q,alt:"Abstra cloud logo"},null,-1)),re=S(()=>C("span",null," Abstra ",-1)),ce=[ne,re];function ie(e,n){return a(),l("div",se,ce)}const le=I(oe,[["render",ie],["__scopeId","data-v-81cd596e"]]),Fe=w({__name:"Workspace",setup(e){return(n,d)=>{const c=x("router-view");return a(),p(U,{"full-canvas":""},{navbar:t(()=>[o(r(Y),{style:{padding:"5px 25px"}},{title:t(()=>[o(le)]),extra:t(()=>[o(X,{"show-github-stars":"","show-v-s-code-button":""})]),_:1})]),sidebar:t(()=>[o(ae,{class:"sidebar"})]),content:t(()=>[o(c)]),_:1})}}});export{Fe as default};
//# sourceMappingURL=Workspace.5ab50ae3.js.map
