import{g as i}from"./api.8bd36db0.js";import{P as m}from"./Passwordless.5f2ec964.js";import{a as f}from"./asyncComputed.ac1a0197.js";import{W as p}from"./WidgetsFrame.ebd50b14.js";import{d as u,eA as l,eB as _,b as c,ev as y,e as g,u as a,c as h,w,ex as b,f as v,v as k}from"./outputWidgets.9bb29762.js";import"./runnerData.84b552ce.js";import"./url.c222fac4.js";import"./index.7dcd1439.js";import"./pubsub.90d4935e.js";import"./index.15996575.js";import"./icons.d08bf04b.js";import"./CircularLoading.9425ae48.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4946a3fd-781c-4328-af36-934acfdac34c",e._sentryDebugIdIdentifier="sentry-dbid-4946a3fd-781c-4328-af36-934acfdac34c")}catch{}})();const x={class:"login"},I=u({__name:"Login",setup(e){const t=l(),s=_(),{result:o}=f(i),d=()=>{const{redirect:r,...n}=s.query;if(r){t.push({path:r,query:n,params:s.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(c(),y("div",null,[g("div",x,[a(o)?(c(),h(p,{key:0,"main-color":a(o).mainColor,theme:a(o).theme,"font-family":a(o).fontFamily,style:{width:"100vw"}},{default:w(()=>[v(m,{onDone:d})]),_:1},8,["main-color","theme","font-family"])):b("",!0)])]))}});const A=k(I,[["__scopeId","data-v-33714d9d"]]);export{A as default};
//# sourceMappingURL=Login.6e40062c.js.map
