import{F as t}from"./Form.472b1af8.js";import{b2 as d,cn as n}from"./outputWidgets.9bb29762.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="259d3b80-d501-47dd-91e3-dea9b793bbe7",e._sentryDebugIdIdentifier="sentry-dbid-259d3b80-d501-47dd-91e3-dea9b793bbe7")}catch{}})();t.useInjectFormItemContext=d;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.d6e0013f.js.map
