import{S as p}from"./Sidebar.51b806e5.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.7fb12854.js";import{M as d,N as l,O as u}from"./icons.d08bf04b.js";import{d as b,eB as f,H as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.9bb29762.js";import{a as w}from"./asyncComputed.ac1a0197.js";import"./router.f15646c4.js";import"./index.2f604abe.js";import{O as z}from"./organization.a9e9abb1.js";import{B as h}from"./BaseLayout.74bb733b.js";import"./index.b2ab466e.js";import"./logo.084e5d7c.js";import"./Text.5324981a.js";import"./Base.abff5e35.js";import"./Typography.184e8c0b.js";import"./index.3a61abce.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Form.472b1af8.js";import"./hasIn.fa8167cd.js";import"./popupNotifcation.b12790e0.js";import"./index.cf4c23b9.js";import"./record.dd7b0559.js";import"./pubsub.90d4935e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="11b86e13-e233-4a7e-ab25-04e8838d0edc",o._sentryDebugIdIdentifier="sentry-dbid-11b86e13-e233-4a7e-ab25-04e8838d0edc")}catch{}})();const Q=b({__name:"Organization",setup(o){const i=f().params.organizationId,{result:t}=w(()=>z.get(i)),n=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Editors",icon:l,path:"editors"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(c,{breadcrumb:n.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{Q as default};
//# sourceMappingURL=Organization.3f0b2f3d.js.map
