import{v as t,b as s,ev as a}from"./outputWidgets.9bb29762.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4a291a1b-9c39-4dd3-80a7-4e97636923a9",e._sentryDebugIdIdentifier="sentry-dbid-4a291a1b-9c39-4dd3-80a7-4e97636923a9")}catch{}})();const o={},r={class:"organization-settings"};function d(e,n){return s(),a("div",r,"Organization settings")}const f=t(o,[["render",d]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.3921e0ea.js.map
